function [Mask]=MaskDisk(xy,L,C,R)

%-------------------------------------------------------------------------%
% Programmed by: Corinne Fournier and Mozhdeh Seifi - Laboratoire Hubert Curien 
%                               http://laboratoirehubertcurien.fr/
%
% Contact : corinne.fournier@univ_st_etienne.fr
% Sept 2011
%-------------------------------------------------------------------------%
%
% Goal : Calculate a binary mask for inverse problems approach, to remove unwanted signal
%-------------------------------------------------------------------------%
% License owner: Mozhdeh Seifi, Corinne Fournier, Loic Denis
%
% This work is licensed under a Creative Commons Attribution 
% Non-Commercial No Derivatives 3.0 France license. In essence, 
% you are free to copy and communicate the work in its current form
% for non-commercial purposes, as long as you attribute the authors
% and abide by the license terms.
% You may not alter or adapt the work in any way.
%
% To view a copy of this license, visit
% http://creativecommons.org/licenses/by-nc-nd/3.0/
%-------------------------------------------------------------------------%
% inputs:  
% xy : [vertical_coordinate horizontal coordinate] of the particle on sensor (unit meters)
%                             --------------------->
%                            |          x
%                            |
%                            |
%                            |
%                            V y   
% L:Line,C:Column Size of the sensor in pixels
% R : the radius of the Mask in pixels
%-------------------------------------------------------------------------%
% outputs: 
% Mask : the binary Mask same size as L,C. 0 inside the disks with raduis R
% on the xy positions, 1 everywhere else
%-------------------------------------------------------------------------%
% Test: 
% [M]=MaskDisk([1 100;-50 200; 300 -300],1024,1280,50)
%-------------------------------------------------------------------------%


if ((numel(R)~=size(xy,1)) && (numel(R)~=size(xy,2)))
    if size(R,1)==1
        R=ones(1,size(xy,1))*R;
    else
        fprintf('R should have the same number of rows as XY or be one scalar\n');
    end
end
R=reshape(R,[1 numel(R)]);
R=R.*R;

M=ones(L,C);
Mask=ones(L,C);
[y x]=meshgrid(-C/2:C/2-1,-L/2:L/2-1);
for c=1:size(xy,1)
    M=(x-xy(c,1)).^2+(y-xy(c,2)).^2;
    ind=find(M<R(c));
    M(find(M<R(c)))=0;
    M(find(M==R(c)))=0;
    M(find(M>R(c)))=1;
    Mask=Mask.*M;
    
%     figure;imshow(Mask);title('Mask')
%     figure;imshow(M);title('M')
end

%  M=1-M;

